summaryrefslogtreecommitdiffstats
path: root/drivers/staging/greybus/greybus_id.h
diff options
context:
space:
mode:
authorGreg Kroah-Hartman <greg@kroah.com>2014-12-19 14:56:32 -0800
committerGreg Kroah-Hartman <greg@kroah.com>2014-12-19 15:35:44 -0800
commitedb0e0b5a17d28c7207197f415c41ab25e75b5d5 (patch)
tree75d1f51a3aaf7c10e8bac5046eb8ff63ab9e35b0 /drivers/staging/greybus/greybus_id.h
parent4ab9b3c24b009fdc55465977153c5deffd31b0c0 (diff)
greybus: interface: rename greybus_interface_block_id to greybus_interface_id
This moves the id structure name to not have "block" in it, as that doesn't make sense anymore with the renaming of the gb_interface structure. Reviewed-by: Alex Elder <elder@linaro.org> Signed-off-by: Greg Kroah-Hartman <greg@kroah.com>
Diffstat (limited to 'drivers/staging/greybus/greybus_id.h')
-rw-r--r--drivers/staging/greybus/greybus_id.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/staging/greybus/greybus_id.h b/drivers/staging/greybus/greybus_id.h
index da70aab54ab0..53da8e71d674 100644
--- a/drivers/staging/greybus/greybus_id.h
+++ b/drivers/staging/greybus/greybus_id.h
@@ -9,7 +9,7 @@
#include <linux/mod_devicetable.h>
-struct greybus_interface_block_id {
+struct greybus_interface_id {
__u16 match_flags;
__u16 vendor;
__u16 product;
@@ -18,7 +18,7 @@ struct greybus_interface_block_id {
kernel_ulong_t driver_info __aligned(sizeof(kernel_ulong_t));
};
/* Used to match the greybus_interface_block_id */
#define GREYBUS_ID_MATCH_VENDOR BIT(0)
#define GREYBUS_ID_MATCH_PRODUCT BIT(1)
#define GREYBUS_ID_MATCH_SERIAL BIT(2)
@@ -18,7 +18,7 @@ struct greybus_interface_block_id {
kernel_ulong_t driver_info __aligned(sizeof(kernel_ulong_t));
};
-/* Used to match the greybus_interface_block_id */
+/* Used to match the greybus_interface_id */
#define GREYBUS_ID_MATCH_VENDOR BIT(0)
#define GREYBUS_ID_MATCH_PRODUCT BIT(1)